@@ -1,7 +1,7 @@
-from .__private.concepts import Event, EventHandler
-from .__private.elements import \
+from ._private._concepts import Event, EventHandler
+from ._private._elements import \
     InternalPipelineElement, \
     EventGenerator, EventListener, \
     EventSource, EventAnalyzer, EventSink, \
     TriggererEventSource, TriggerableEventSource, TriggerableEventBatchSource
-from .__private.pipeline import Pipeline
+from ._private._pipeline import Pipeline
